<?php

namespace SuperRhino\Utils\Cache;

use Psr\SimpleCache\CacheInterface;

interface CacheAdapterInterface extends CacheInterface {

    /**
     * @param $key
     * @param callable $callback
     * @param null $ttl
     * @param float|null $beta 防缓存践踏设置, 大于0, 默认1, 数值越大意味着越早重新缓存, INF 表示强制重新缓存
     * @return mixed
     */
    public function getCallback($key, callable $callback, $ttl = null, ?float $beta = null);

    /**
     * Return state of existence and data at the same time.
     * @param null|mixed $default
     */
    public function fetch(string $key, $default = null): array;

    /**
     * Add key to the collection
     * @param string $collector
     * @param string $key
     * @return bool
     */
    public function addKey(string $collector, string $key): bool;

    /**
     * get keys to the collection
     * @param string $collector
     * @return array
     */
    public function keys(string $collector): array;

    /**
     * @param string $collector
     * @param ...$key
     * @return bool
     */
    public function delKey(string $collector, ...$key): bool;

    /**
     * Clean up data of the same prefix.
     */
    public function clearPrefix(string $prefix): bool;
}